/*
 * Copyright (C) 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
	File: H550.H
	Project: HOSTESS 550 Device Driver for IRIX 5.1
	Author: Rick McLeod (plagarized from Lori Slater's SCO Unix source)
	Date: 8/11/93
	Copyright (c) 1993 Silicon Graphics Computer Systems  
			All Rights Reserved
	Copyright (c) 1989-1990 COMTROL Corporation   All Rights Reserved
*/

#define N_ADAPTERS	4
#define MAX_PORTS	8		/* max number of ports per adapter */
#define N_PORTS		(N_ADAPTERS*MAX_PORTS)

/* Define 16550 registers ... */
#define RBR	0		/* receiver buffer register (RO) */
#define THR	0		/* transmitter holding register (WO) */
#define IER	1		/* interrupt enable register */
#define IIR	2		/* interrupt identification register (RO) */
#define FCR	2		/* FIFO control register (WO) */
#define LCR	3		/* line control register */
#define MCR	4		/* modem control register */
#define LSR	5		/* line status register */
#define MSR	6		/* modem status register */
#define POLL	7		/* mask/poll register */
#define MASK	7		/* mask/poll register */
#define DLL	0		/* divisor latch - least sig. byte */
#define DLM	1		/* divisor latch - most sig. byte */

/* Define bits of interrupt enable register ... */
#define ERBFI		0x01	/* received data available */
#define ETBEI		0x02	/* tranmitter holding register empty */
#define ELSI		0x04	/* receiver line status */
#define EDSSI		0x08	/* modem status */

/* Define bits of line control register ... */
#define WLS0		0x01	/* word length select bit 0 */
#define WLS1		0x02	/* word length select bit 1 */
#define STB		0x04	/* number of stop bits */
#define PEN		0x08	/* parity enable */
#define EPS		0x10	/* even parity select */
#define BRK		0x40	/* set break */
#define DLAB		0x80	/* divisor latch access bit */

/* Define bits of modem control register ... */
#define DTR		0x01	/* data terminal ready */
#define RTS		0x02	/* request to send */
#define OUT2		0x08	/* enable adapter interrupts */

/* Define bits of line status register ... */
#define DR		0x01	/* data ready */
#define OE		0x02	/* overrun error */
#define PE		0x04	/* parity error */
#define FE		0x08	/* framing error */
#define BI		0x10	/* break interrupt */
#define THRE		0x20	/* transmit butter empty */

/* Define bits of modem status register ... */
#define DCTS		0x01	/* delta clear to send */
#define DDSR		0x02	/* delta data set ready */
#define TERI		0x04	/* trailing edge ring indicator */
#define DDCD		0x08	/* delta data carrier detect */
#define CTS		0x10	/* clear to send */
#define DSR		0x20	/* data set ready */
#define RI		0x40	/* ring indicator */
#define DCD		0x80	/* data carrier detect */

/* Define bits of FIFO Control register ... */
#define	FIFOENB		0x01	/* Enable FIFO's */
#define	RFIFO_RST	0x02	/* Reset Receive FIFO */
#define TFIFO_RST	0x04	/* Reset Transmit FIFO */

/* Miscellaneous defines ... */
#define TRIGGER		8	/* receive FIFO trigger level */

/* Define bits of Interrupt ID Register and the Interrupt types... */
#define INTR_PEND	0x01	/* Interrupt Pending */
#define MODEM_STAT	0x00	/* Modem Status Interrupt */
#define THREI		0x02	/* Transmit Holding Register Empty Interrupt */
#define RDATA_AVAIL	0x04	/* Receive Data Available Interrupt */
#define RLINE_STAT	0x06	/* Receiver Line Status Interrupt */
#define CHAR_TIME	0x0c	/* Character Timeout Interrupt */

/* some macros */

#define LOCK_PORT(dp)       spltty()
#define UNLOCK_PORT(dp,s)   splx(s)


